import {Component, OnInit} from '@angular/core';
import {toUpper, startsWith, length} from 'ramda';
import {ApiService} from "../../service/api.service";
import {Character} from "../../model/character.model";

@Component({
    selector: 'app-characters',
    templateUrl: './characters.component.html',
    styleUrls: ['./characters.component.scss'],
    providers: [ApiService]
})
export class CharactersComponent implements OnInit {

    constructor(private apiService: ApiService) {
    }

    /**
     *  Definice artibutů komponenty
     **/
    searchedExpression: any;

    /**
     *  Zde jsou uloženy postavy, která se dodáhli při inicializaci komponenty, toto pole se nemění
     **/
    characters: Character[];

    /**
     *  Zde jsou uloženy vyfiltrované postavy, na základě hladaného řetězce, toto pole se mění a dochází
     *  tedy k side-effectu, který je při využití paradigmatu funkcionálního programování nežádoucí.
     **/
    filteredCharacters: Character[];

    /**
     *  Funkce, která kontroluje, jestli jméno postavy se schoduje s hledaným řetězcem. Pro zjednodušení dochází
     *  k využití funkcí z knihovny Ramda
     **/
    checkCharacterName(character) {
        const characterName = toUpper(character.name);

        if (startsWith(toUpper(this.searchedExpression), characterName)) {
            return character;
        }
    };

    /**
     *  Funkce, která filtruje dotažené postavy na základě hledaného řetězce z inputu
     **/
    filterCharactersBySearchedName() {
        const newFilteredCharacters = [];

        for (let i = 0; i < length(this.characters); i++) {

            const checkedCharacter = this.checkCharacterName(this.characters[i]);

            if (checkedCharacter) {
                newFilteredCharacters.push(checkedCharacter);
            }
        }

        this.filteredCharacters = newFilteredCharacters;
    };

    /**
     *  Funkce, která za využití service apiService dotahuje pole charakterů, česky postav.
     **/
    getCharacters(): void {
        this.apiService.getWithAuthorization('/character').subscribe(characters => (this.characters = characters.docs));
    }

    ngOnInit(): void {
        this.getCharacters();
    }

}
