import {Component, OnInit} from '@angular/core';
import {Router} from '@angular/router';
import {Movie} from "../../model/movie.model";
import {ApiService} from "../../service/api.service";

@Component({
    selector: 'app-movie-detail',
    templateUrl: './movie-detail.component.html',
    styleUrls: ['./movie-detail.component.scss'],
    providers: [ApiService]
})
export class MovieDetailComponent implements OnInit {

    /**
     *  Konstruktor, který bere dva atributy router a apiservice. Tímto zápise dojde k zpřístupnění atributů
     *  v rámci komponenty bez nutnosti použití zápisu this.router = router...
     **/
    constructor(private router: Router, private apiService: ApiService) {
    }

    movie: Movie;

    /**
     *  Za použití api service dochozí k dotažení a uložení filmů do atributu třídy movie. URL je v tomto případě
     *  získano za pomocí angular routeru a jeho funkce router.url, která vrací textový řetězec adresy v prohlížeči,
     *  který je potřeba pro vykonání API volání
     **/
    getMovie(): void {
        this.apiService.getWithAuthorization(this.router.url).subscribe(movie => (this.movie = movie));
    }

    /**
     *  Spuštění funkce getMovie() během inicializace komponenty
     **/
    ngOnInit(): void {
        this.getMovie()
    }

}
