import React from 'react';
import PropTypes from 'prop-types';
import './character.scss';

const Character = ({ character }) => {

    /**
     *  Funkce, která zjišťuje, jestli hodnota existuje, pokud ano vrátí ji, jinak vrátí text "IS NOT KNOWN"
     **/
    const valueCheck = (value) => !value ? 'IS NOT KNOWN' : value;

    /**
     * Funkce, která na základě hodnoty "gender" z props "character" rozhoduje, jaký obrázek má být použit
     **/
    const setProperImage = (gender) => {
        if (gender === 'Male' || gender === 'male') {
            return 'https://cdn0.iconfinder.com/data/icons/famous-character-vol-2-colored/48/JD-41-512.png';
        } else if (gender === 'Female' || gender === 'female') {
            return 'https://cdn0.iconfinder.com/data/icons/famous-character-vol-2-colored/48/JD-42-512.png';
        } else {
            return 'https://cdn0.iconfinder.com/data/icons/famous-character-vol-2-colored/48/JD-40-512.png';
        }
    };

    return (
        <div className="character">
            <img
                className="character__image"
                src={setProperImage(character.gender)}
                alt={'not found'}
            />
            <div className="character__content">
                <h2 className="character__content__heading">{character.name}</h2>
                <p>Race: {valueCheck(character.race)}</p>
                <p>Gender: {valueCheck(character.gender)}</p>
                <p>Realm: {valueCheck(character.realm)}</p>
                <p>Birth: {valueCheck(character.birth)}</p>
                <p>Death: {valueCheck(character.death)}</p>
                <p>Spouse: {valueCheck(character.spouse)}</p>
                <p>Wiki: <a href={character.wikiUrl && character.wikiUrl}>{valueCheck(character.wikiUrl)}</a></p>
            </div>
        </div>
    );
};

Character.propTypes = {
    /**
     *  Objekt, který obsahuje údaje o characteru, které se nádledně mapují
     **/
    character: PropTypes.any.isRequired,
};

export default Character;
