import React, { useState } from 'react';
import { prepend } from 'ramda';
import Paper from '../../components/Paper';
import './discussion.scss';
import Message from './components/Message';

const Discussion = () => {

    /**
     *  Hook, který slouží pro uložení a nastavení zpráv komponenty.
     **/
    const [messages, setMessages] = useState([
        {
            id: '3',
            date: '13. 1. 2020',
            user: 'Petr Pavel',
            content: `Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Etiam bibendum elit eget erat. 
                Nullam lectus justo, vulputate eget mollis sed, tempor sed magna. Nulla non lectus sed nisl molestie
                malesuada. Phasellus rhoncus. Nam quis nulla. Ut enim ad minima veniam, quis nostrum exercitationem
                ullam corporis suscipit laboriosam, nisi ut aliquid ex ea commodi consequatur? Pellentesque pretium 
                lectus id turpis. Fusce dui leo, imperdiet in, aliquam sit amet, feugiat eu, orci. Aliquam erat 
                volutpat. Mauris elementum mauris vitae tortor. Mauris dictum facilisis augue. Integer rutrum, orci 
                vestibulum ullamcorper ultricies, lacus quam ultricies odio, vitae placerat pede sem sit amet enim. 
                Donec vitae arcu. Suspendisse nisl. Vestibulum fermentum tortor id mi. Integer imperdiet lectus quis 
                justo. Aliquam ante. Morbi scelerisque luctus velit.`,
        },
        {
            id: '2',
            date: '14. 1. 2020',
            user: 'Petr Pavel',
            content: `Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Etiam bibendum elit eget erat. 
                Nullam lectus justo, vulputate eget mollis sed, tempor sed magna. Nulla non lectus sed nisl molestie
                malesuada. Phasellus rhoncus. Nam quis nulla. Ut enim ad minima veniam, quis nostrum exercitationem
                ullam corporis suscipit laboriosam, nisi ut aliquid ex ea commodi consequatur? Pellentesque pretium 
                lectus id turpis. Fusce dui leo, imperdiet in, aliquam sit amet, feugiat eu, orci. Aliquam erat 
                volutpat. Mauris elementum mauris vitae tortor. Mauris dictum facilisis augue. Integer rutrum, orci 
                vestibulum ullamcorper ultricies, lacus quam ultricies odio, vitae placerat pede sem sit amet enim. 
                Donec vitae arcu. Suspendisse nisl. Vestibulum fermentum tortor id mi. Integer imperdiet lectus quis 
                justo. Aliquam ante. Morbi scelerisque luctus velit.`,
        },
        {
            id: '1',
            date: '15. 1. 2020',
            user: 'Petr Pavel',
            content: `Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Etiam bibendum elit eget erat. 
                Nullam lectus justo, vulputate eget mollis sed, tempor sed magna. Nulla non lectus sed nisl molestie
                malesuada. Phasellus rhoncus. Nam quis nulla. Ut enim ad minima veniam, quis nostrum exercitationem
                ullam corporis suscipit laboriosam, nisi ut aliquid ex ea commodi consequatur? Pellentesque pretium 
                lectus id turpis. Fusce dui leo, imperdiet in, aliquam sit amet, feugiat eu, orci. Aliquam erat 
                volutpat. Mauris elementum mauris vitae tortor. Mauris dictum facilisis augue. Integer rutrum, orci 
                vestibulum ullamcorper ultricies, lacus quam ultricies odio, vitae placerat pede sem sit amet enim. 
                Donec vitae arcu. Suspendisse nisl. Vestibulum fermentum tortor id mi. Integer imperdiet lectus quis 
                justo. Aliquam ante. Morbi scelerisque luctus velit.`,
        },
    ]);

    /**
     *  Hook, který slouží pro uložení hodnoty inputu v případě, že zadáváme novou zprávu do diskuze
     **/
    const [messageContent, setMessageContent] = useState('');

    /**
     *  Mapuje všechny zprávy, které jsou uloženy v našem hooku do komponenty <Message>
     **/
    const renderMessages = () => messages.map((message) => <Message key={message.id} message={message}/>);

    /**
     *  Funkce, která slouží pro přidání nové zprávy
     **/
    const addMessage = () => {
        const date = new Date();
        const messageId = messages[0].id + 1;
        const messageUser = 'Adam Černohorský';

        const message = {
            id: messageId,
            date: `${date.toLocaleDateString()} v ${date.toLocaleTimeString()}`,
            user: messageUser,
            content: messageContent,
        };
        /**
         * Funkce prepend z knihovny Ramda slouží pro přidání zprávy na začátek pole. Tím pádem se nové zprávy
         * vykreslují na prvních pozicích, kdežto normální chování by je dávalo na konec pole a tím pádem by
         * byly i na konci diskuze
         **/
        setMessages(prepend(message, messages));
        setMessageContent('');
    };

    return (
        <Paper>
            <h1>Discussion</h1>
            <p>
                V rámci této stránky si představíme možnosti práce se statem komponenty za pomoci simulované diskuze.
                Diskuze funguje na principu renderování seznamu příspěvků, které jsou sdružovány v rámci pole, které je
                ve statu komponenty. Po kliknutí na tlačítko odeslat pak dojde k updatu statu komponenty novou hodnotou
                a komponenta je re-renderována a tím pádem je i náš příspěvek viditelný. V případě existující API by
                bylo možné namísto statu udržovat seznam příspěvků na beckendu, nicméně tato práce je zaměřena na tvorbu
                UI, tudíž jsem zvolil tuto provizorní variantu, jelikož práce s API byla ukázána v komponentách Movie.
                Nové příspěvky se pak přidávají pomocí textarey a odesláním buttonem níže, který zavolá funkci, která
                přidá tuto zprávu do již existujícího pole zpráv.
            </p>

            <div className="discussion">
                <h2>New message</h2>
                <textarea
                    className="discussion__input"
                    value={messageContent}
                    onChange={(event) => setMessageContent(event.target.value)}
                />
                <button
                    className="discussion__button"
                    disabled={!messageContent}
                    onClick={() => addMessage()}
                >
                    {!messageContent ? 'YOUR MESSAGE IS EMPTY :/' : 'ADD NEW MESSAGE !'}
                </button>

                {renderMessages()}
            </div>
        </Paper>
    );
};

export default Discussion;
