import React, { useEffect, useState } from 'react';
import { useHistory } from 'react-router-dom';
import { split, o, last, isEmpty } from 'ramda';
import { getMovieDetail } from './actions';
import Paper from '../../components/Paper';
import './moviedetail.scss';

const MovieDetail = () => {
    /**
     *  Hook, udržující object hledaného filmu
     **/
    const [movie, setMovie] = useState({});

    /**
     *  Funkce, která získá z browser history aktuální adresu a z té pomocí ramda funkcí vyseparuje movie id, které
     *  je následně použito pro dotažení informací o konkrétním filmu. Tato funkce slouží především jako ukázka
     *  funkcionálního programování s použitím point-free a no-side-effects.
     **/
    const getMovieId = o(last, split('/'))(useHistory().location.pathname);

    /**
     *  Hook, dotahující informace o filmu. If a isEmpty() zajistí, že k dotažení dojde pouze pokud ještě
     *  nedošlo k předchozímu dotažení.
     **/
    useEffect(() => {
        if (isEmpty(movie)) {
            getMovieDetail(getMovieId).then((res) => setMovie(res.data));
        }
    });

    return (
        <Paper>
            <h1>MovieDetail</h1>
            <p>
                Tato stránka slouží k zobrazení detailu vybraného filmu. Mezi hlavním úkolem, s kterými bylo nutné se
                vypořádat, bylo vyřešení dotažení konkrétního filmu. Tento problém jsem se rozhodl řešit za pomocí
                funkcionálního programování a knihovny ramda, kde jsem za pomocí compozice vyparsoval id z URL v
                prohlížeči a následně provolal připravené API. V případě, pokud bychom s aplikací používali například
                Redux, bylo by možné na kliknutí vybranou knihu uložit do storu a následné přes selector k ní
                přistupovat což by ušetřilo jedno volání beckendu. Nicméně rozhodl jsem se, že problematika reduxu je
                tak rozsáhlá, že nebude v této bakalářské práci prezentována, ale dojte pouze k odkazu na tuto
                technologii.
            </p>

            <div className="movie-detail">
                <img
                    className="movie-detail__image"
                    alt={'Not found'}
                    src={'https://images-na.ssl-images-amazon.com/images/I/311cT2c6%2BUL._SX310_BO1,204,203,200_.jpg'}
                />
                <div className="movie-detail__content">
                    <h2 className="movie-detail__content__heading">{movie.name}</h2>
                    <p>Budget: {movie.budgetInMillions} millions</p>
                    <p>Duration: {movie.runtimeInMinutes} minutes</p>
                    <p>Awards wins: {movie.academyAwardWins}</p>
                </div>
            </div>
        </Paper>
    );
};

export default MovieDetail;
