import React, { useEffect, useState } from 'react';
import { isEmpty } from 'ramda';
import { getAllMovies } from './actions';
import Paper from '../../components/Paper';
import './movies.scss';
import Movie from './components/Movie';


const Movies = () => {

    /**
     *  Hook udržující pole filmů.
     **/
    const [movies, setMovies] = useState([]);

    /**
     *  Funkce, která mapuje pole filmů na komponentu <Movie>
     **/
    const renderMovies = movies.map((movie) => <Movie key={movie._id} movie={movie}/>);

    /**
     *  Hook zajišťující dotažení všech filmů. If a isEmpty zajistí, že k dotažení dojde pouze jednou
     **/
    useEffect(() => {
        if (isEmpty(movies)) {
            getAllMovies().then((res) => setMovies(res.data.docs));
        }
    });

    return (
        <Paper>
            <h1>Movies</h1>
            <p>
                Na této stránce dotahujeme seznam filmů a následně mapujeme informace, které nám vrací API do vlastních
                komponent, které na stránce následně zobrazujeme. Jedná se o funkcionální komponentu, která využívá
                hooky. Je dobré si uvědomit, že hook useEffect zároveň může sloužit jako metoda životního cyklu, která
                hlídá update komponenty. Proto je třeba přidat podmínku, která říká, že dotaz na beckend se provede
                pouze tehdy, pokud žádné filmy zatím nebyly dosaženy - výchozí hodnota je prázdné pole.
            </p>
            <div className="movies">
                {renderMovies}
            </div>
        </Paper>
    );
};

export default Movies;
