import React from 'react';
import PropTypes from 'prop-types';
import { useHistory } from 'react-router-dom';
import './movie.scss';

const Movie = ({ movie }) => {

    /**
     *  Hook, který nám vrátí history object, s kterým je možné dále pracovat. V této komponentě se využívá
     *  jeho metody push(), která umí změnit url v prohlížeči a spolu s routerem tak zajistí navigaci.
     **/
    const history = useHistory();

    return (
        <div
            className="movie"
            onClick={() => history.push(`/movie/${movie._id}`)}
        >
            <img
                className="movie__image"
                alt={'Not found'}
                src={'https://images-na.ssl-images-amazon.com/images/I/311cT2c6%2BUL._SX310_BO1,204,203,200_.jpg'}
            />
            <div className="movie__content">
                <h3 className="movie__content__heading">{movie.name}</h3>
                <p>Budget: {movie.budgetInMillions} millions</p>
                <p>Duration: {movie.runtimeInMinutes} minutes</p>
                <p>Awards wins: {movie.academyAwardWins}</p>
            </div>
        </div>
    );
};

Movie.propTypes = {
    /**
     *  Objekt movie, který obsahuje všechny potřebné informace, které se v rámci této komponenty mapují
     **/
    movie: PropTypes.any.isRequired,
};

export default Movie;
